/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2019 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.takes.rq;

import java.io.ByteArrayInputStream;
import lombok.EqualsAndHashCode;
import org.takes.Request;
import org.takes.misc.Utf8String;

/**
 * Request with body.
 *
 * <p>The class is immutable and thread-safe.
 * @since 0.22
 */
@EqualsAndHashCode(callSuper = true)
public final class RqWithBody extends RqWrap {

    /**
     * Ctor.
     * @param req The request.
     * @param bdy The body.
     */
    public RqWithBody(final Request req, final CharSequence bdy) {
        super(
            new RequestOf(
                req::head,
                () -> new ByteArrayInputStream(
                    new Utf8String(bdy.toString()).asBytes()
                )
            )
        );
    }
}
